@@ -85,121 +85,22 @@ def createBTT(filename, numElements):
     
     #make sure that the filename is an authentic string
     #type...
-    if(type(filename) == type("")):
+    if(type(filename) == type("") and type(numElements) == type(9)):
 
-        #check how large numElements is...
-        if(numElements > 1000 and numElements <= 1000000):
-            
-            #see how many columns will be needed...
-            for x in range(1,1001):
+        #check if num elements is less than or equal to 1000...
+        if(numElements <= 1000):
 
-                #check if sum is greater than numElements...
-                if((x * 1000) >= numElements):
+            #create memmap...
+            tree =  np.memmap(filename, dtype='float32', mode='w+', shape=(1000,1))
 
-                    #create memmap...
-                    tree =  np.memmap(filename, dtype='float32', mode='w+', shape=(1000,x))
-
-                    #now append tree to BT
-                    BT.append(tree)
-
-                    #break from the for loop...
-                    break
-
-        elif(numElements > 1000000):
-
-            #In the case of more than 1000000, two or more memmaps will be created...
-
-            #file counter variable...
-            counter = 1
-            
-            #use a while loop to analyze the situation...
-            while(True):
-
-                #Create the first memmap...
-                tree =  np.memmap(filename + str(counter), dtype='float32', mode='w+', shape=(1000,1000))
-
-                #increment the file counter variable...
-                counter = counter + 1
-                
-                #append tree to the memmap list BT...
-                BT.append(tree)
-
-                #Now subtract 1000000 from numElements...
-                numElements = numElements - 1000000
-
-                #check to see if numElements is still greater than 1000000
-                if(numElements < 1000000):
-
-                    #break from the while loop...
-                    break
-
-            #Now create the last memmap...
-            #But first find out how many columns will be needed if
-            #numElements is greater than 1000...
-            if(numElements > 1000):
-                
-                #columns variable...
-                cols = None
-
-                #***NOTE: The columns variable won't intially hold the number
-                #of columns the memmap should have. First the number of digits
-                #that must be extracted will be computed and assigned to cols.
-                #This value will then be used to extract all digits in front of
-                #the three zeros (with three being the most). The extracted digits
-                #will then be concatenated in string form and then converted to
-                #type integer -> This final number will be the number of columns needed...
-
-                #compute number of columns...
-                if(len(str(numElements)) % 3 == 0):
-
-                    #three columns will be needed...
-                    cols = 3
-
-                elif(len(str(numElements)) == 5):
-
-                    #two colums will be needed...
-                    cols = 2
-
-                else:
-
-                    #one column will be needed...
-                    cols = 1
-
-                #make a copy of cols...
-                copy = cols
-                    
-                #Now extract the digits...
-                cols = int(str(numElements)[0:cols])
-                
-                #extract leftovers...
-                leftover = int(str(numElements)[copy:])
-                
-                #add the correct number of columns...
-                if(leftover > 0):
-
-                    #now create the last memmap...
-                    tree = np.memmap(filename + str(counter), dtype='float32', mode='w+', shape=(1000,cols+1))
-
-                else:
-
-                    #now create the last memmap...
-                    tree = np.memmap(filename + str(counter), dtype='float32', mode='w+', shape=(1000,cols))
-
-                #increment the counter...
-                counter = counter + 1
-                
-                #Now append the tree to the BT list...
-                BT.append(tree)
-            
-        elif(numElements != 0):
-
-            #create a 1000x1 memmap matrix for the efficient binary tree
-            #implementation...
-            tree = np.memmap(filename, dtype='float32', mode='w+', shape=(1000,1))
-            
-            #append tree to the global BT variable...
+            #now append tree to BT
             BT.append(tree)
 
+        else:
+
+            #split the input...
+            splitInput(BT, str(numElements), filename)
+
         #append BT to the info array...
         INFO.append(BT)
 
@@ -215,6 +116,14 @@ def createBTT(filename, numElements):
         #return INFO...
         return INFO
 
+    else:
+
+        #print error message...
+        print("The file name was not of type string...")
+
+        #return -1...
+        return -1
+
 #Breadth first search algorithm...
 def BreadthFS(BT, value):
 
@@ -316,7 +225,7 @@ def MResize(BT):
     if(cols == 1000):
 
         #since cols == 1000, we need a whole new memmap...
-        tree = np.memmap("NewMemmapOResize"+str(length+1), dtype='float32', mode='w+', shape=(1000,1))
+        tree = np.memmap("New_Memmap_Resize_"+str(length+1), dtype='float32', mode='w+', shape=(1000,1))
 
         #Now append the new memmap to the BT list...
         BT.append(tree)
@@ -349,25 +258,7 @@ def isFull(NUMNODES, LEVEL):
 
         #return -1 since the tree is not full
         return -1
-
-#Breadth first search based on index...
-def BreadthFirstSelect(BT, start, INDEX, value):
-
-    #use a for loop to iterate across all index values...
-    for x in range((INDEX - start) + 1):
-
-        #decompose the current index...
-        x, y, z = decomp(start + x)
-        
-        #now make the comparison...
-        if(BT[x][y][z] == value):
-
-            #return the index values associated with
-            #the matched value...
-            return x, y, z
-
-    #return -1 since no match was made...
-    return -1, -1, -1
+    
 
 #Decompose Index...                                                         
 def Decomp(index):
@@ -475,6 +366,12 @@ def RightChild(index):
 #extract the max value...
 def ExtractMax(BT, INDEX, LEVEL):
 
+    #see if INDEX == -1
+    if(INDEX == -1):
+
+        #return the same values...
+        return "NULL", INDEX, LEVEL
+    
     #remove value from supernode (root)
     value = BT[0][0][0]
 
@@ -491,7 +388,7 @@ def ExtractMax(BT, INDEX, LEVEL):
     INDEX = INDEX - 1
 
     #update the LEVEL variable...
-    if(INDEX == 0):
+    if((INDEX == 0 or INDEX == -1) and LEVEL != 0):
 
         LEVEL = 0
 
@@ -514,16 +411,176 @@ def ExtractMax(BT, INDEX, LEVEL):
 
                 #break out of for loop...
                 break
+    
+    #move the new root value to appropriate place...
+    return downwardT(a, b, c, value, INDEX, LEVEL, BT)
 
-    #start value for while loop...
+#add value to the MAX-Binary-Heap...
+def MAXBTAdd(BT, LEVEL, INDEX, NUMNODES, value):
+
+    #see if resizing is necessary...
+    if(NUMNODES+1 > BT[len(BT)-1].shape[1]*1000):
+
+        #resize the memmap...
+        MResize(BT)
+    
+    #first add the value to the position
+    #INDEX + 1
+
+    #decompose INDEX + 1 so it's position can
+    #be accessed...
+    a, b, c = Decomp(INDEX + 1)
+
+    #starting index for upward traversal...
+    index = INDEX + 1
+
+    #see if LEVEL needs to be incremented...
+    sum = 0
+
+    #sum all the way to LEVEL...
+    for x in range(1, LEVEL+1):
+
+        #increment sum...
+        sum = sum + 2**x
+
+    #increment LEVEL based on sum...
+    if(INDEX+1 > sum):
+
+        #increment LEVEL...
+        LEVEL = LEVEL + 1
+
+    #assign value to position BT[a][b][c]
+    BT[int(a)][int(b)][int(c)] = float(value)
+
+    #traverse new value upwards to appropriate place...
+    upwardT(a, b, c, index, value, BT)
+
+    #return  the new INDEX and LEVEL...
+    return LEVEL, (INDEX + 1), (NUMNODES + 1)
+        
+#Traverse Back left...                                                                                                                                                                                           
+def LeftBack(index):
+
+    #compute the parent index...                                                                                                                                                                     
+    parent = (index - 1) / 2
+
+    #return parent                                                                                                                                                                       
+    return parent
+
+#Traverse Back right...                                                                                                                                                                         
+def RightBack(index):
+
+    #compute the parent index...                                                                                                                                                                                 
+    parent = (index - 2) / 2
+
+    #return the parent index                                                                                                                                             
+    return parent
+
+#split the input and create binary heaps
+#based on the split input...
+def splitInput(List, numElements, filename):
+
+    #index multiplier..
+    index = len(numElements) - 3
+
+    #length multiplier...
+    length = len(numElements)
+    
+    #temporary memmap reference...
+    tree = None
+
+    #memmap column count...
+    col = 0
+
+    #memmap structure count...
+    structure = 0
+    
+    #negative number flag...
+    negative = 0
+    
+    #use while loop to get number of columns...
+    for x in range(2):
+
+        #see if this is the first iteration...
+        if(x == 0):
+
+            #see if the last three digits are all zeros...
+            temp = numElements[index:length]
+
+            #check for all zeros...
+            if(int(temp) != 0):
+                
+                #get the first segment...
+                col = col + 1
+
+        else:
+
+            #see if index is zero after subtracting another three...
+            if(index - 3 > 0):
+
+                #update col...
+                col = col + int(numElements[index-3:length-3])
+
+            else:
+
+                #update col...
+                col = col + int(numElements[0:length-3])
+
+                #set negative flag...
+                negative = 10
+
+    #get number of structures...
+    if(negative != 10):
+
+        #get structure count...
+        structure = int(numElements[0:length-6])
+
+    #Now create structures...
+    createStructure(List, structure, col, filename)
+
+
+#create the number of strucutres calculated in
+#split input function...
+def createStructure(List, structure, columns, filename):
+
+    #number tracker...
+    num = 0
+    
+    #create the structures...
+    for x in range(structure):
+
+        #get reference...
+        tree = np.memmap(filename + str(x), dtype='float32', mode='w+', shape=(1000,1000))
+
+        #append to the list...
+        List.append(tree)
+
+        #see if x is equal to structure - 1...
+        if(x == structure - 1):
+
+            #assign x+1 to num...
+            num = str(x+1)
+
+    #see if another strucutre is needed...
+    if(columns != 0):
+
+        #create last structure...
+        tree = np.memmap(filename+str(num), dtype='float32', mode='w+', shape=(1000,columns))
+
+        #append to the list...
+        List.append(tree)
+
+
+#downwards traversal function...
+def downwardT(a, b, c, value, INDEX, LEVEL, BT):
+
+    #index value...
     index = 0
 
-    #index components that will keep track of the
-    #new root node value...
+    #index components...
     x, y, z = 0, 0, 0
     
-    #use while loop to move the new root value to it's
-    #appropriate place...
+    #use while loop to perform downward traversal...
     while(True):
 
         #start traversing downwards...
@@ -590,43 +647,13 @@ def ExtractMax(BT, INDEX, LEVEL):
         #return the INDEX value and MAX value...
         return value, INDEX, LEVEL
 
-#add value to the MAX-Binary-Heap...
-def MAXBTAdd(BT, LEVEL, INDEX, NUMNODES, value):
 
-    #see if resizing is necessary...
-    if(NUMNODES+1 > BT[len(BT)-1].shape[1]*1000):
+#upward traveral function...
+def upwardT(a, b, c, index, value, BT):
 
-        #resize the memmap...
-        MResize(BT)
+    #x, y, z values....
+    x, y, z = 0, 0 , 0
     
-    #first add the value to the position
-    #INDEX + 1
-
-    #decompose INDEX + 1 so it's position can
-    #be accessed...
-    a, b, c = Decomp(INDEX + 1)
-
-    #starting index for upward traversal...
-    index = INDEX + 1
-
-    #see if LEVEL needs to be incremented...
-    sum = 0
-
-    #sum all the way to LEVEL...
-    for x in range(1, LEVEL+1):
-
-        #increment sum...
-        sum = sum + 2**x
-
-    #increment LEVEL based on sum...
-    if(INDEX+1 > sum):
-
-        #increment LEVEL...
-        LEVEL = LEVEL + 1
-
-    #assign value to position BT[a][b][c]
-    BT[int(a)][int(b)][int(c)] = float(value)
-
     #use while loop to traverse upwards...
     while(True):
 
@@ -679,24 +706,16 @@ def MAXBTAdd(BT, LEVEL, INDEX, NUMNODES, value):
 
         #break from the loop if this point is reached...
         break
+    
+def main():
 
-    #return  the new INDEX and LEVEL...
-    return LEVEL, (INDEX + 1), (NUMNODES + 1)
-        
-#Traverse Back left...                                                                                                                                                                                           
-def LeftBack(index):
+    a = createBTT("fuck",2000)
+    a[1], a[2], a[3] = MAXBTAdd(a[0], a[1], a[2], a[3], 6)
+    a[1], a[2], a[3] = MAXBTAdd(a[0], a[1], a[2], a[3], 12)
+    print(a[0][0][0][0])
+    b, a[2], a[1] = ExtractMax(a[0], a[2], a[1])
+    b, a[2], a[1] = ExtractMax(a[0], a[2], a[1])
+    b, a[2], a[1] = ExtractMax(a[0], a[2], a[1])
+    print(b)
 
-    #compute the parent index...                                                                                                                                                                     
-    parent = (index - 1) / 2
-
-    #return parent                                                                                                                                                                       
-    return parent
-
-#Traverse Back right...                                                                                                                                                                         
-def RightBack(index):
-
-    #compute the parent index...                                                                                                                                                                                 
-    parent = (index - 2) / 2
-
-    #return the parent index                                                                                                                                             
-    return parent
+main()
